@@ -10,11 +10,11 @@ import (
 	"github.com/fatih/color"
 	"github.com/goreleaser/goreleaser/internal/pipe/defaults"
 	"github.com/goreleaser/goreleaser/pkg/context"
-	"github.com/spf13/cobra"
+	"github.com/muesli/coral"
 )
 
 type checkCmd struct {
-	cmd        *cobra.Command
+	cmd        *coral.Command
 	config     string
 	quiet      bool
 	deprecated bool
@@ -22,14 +22,14 @@ type checkCmd struct {
 
 func newCheckCmd() *checkCmd {
 	root := &checkCmd{}
-	cmd := &cobra.Command{
+	cmd := &coral.Command{
 		Use:           "check",
 		Aliases:       []string{"c"},
 		Short:         "Checks if configuration is valid",
 		SilenceUsage:  true,
 		SilenceErrors: true,
-		Args:          cobra.NoArgs,
-		RunE: func(cmd *cobra.Command, args []string) error {
+		Args:          coral.NoArgs,
+		RunE: func(cmd *coral.Command, args []string) error {
 			if root.quiet {
 				log.SetHandler(cli.New(io.Discard))
 			}
