@@ -1,18 +1,19 @@
 package docker
 
 import (
-	"context"
 	"fmt"
 	"strings"
+
+	"github.com/goreleaser/goreleaser/pkg/context"
 )
 
 type buildPackImager struct{}
 
-func (i buildPackImager) Push(ctx context.Context, image string, flags []string) error {
+func (i buildPackImager) Push(ctx *context.Context, image string, flags []string) error {
 	return dockerImager{}.Push(ctx, image, flags)
 }
 
-func (i buildPackImager) Build(ctx context.Context, root string, images, flags []string) error {
+func (i buildPackImager) Build(ctx *context.Context, root string, images, flags []string) error {
 	if err := runCommand(ctx, "", "pack", i.buildCommand(images, flags)...); err != nil {
 		return fmt.Errorf("failed to build %s: %w", images[0], err)
 	}
