@@ -14,6 +14,7 @@ import (
 	"github.com/apex/log"
 	"github.com/goreleaser/goreleaser/internal/artifact"
 	"github.com/goreleaser/goreleaser/internal/client"
+	"github.com/goreleaser/goreleaser/internal/commitauthor"
 	"github.com/goreleaser/goreleaser/internal/pipe"
 	"github.com/goreleaser/goreleaser/internal/tmpl"
 	"github.com/goreleaser/goreleaser/pkg/config"
@@ -37,12 +38,7 @@ func (Pipe) Default(ctx *context.Context) error {
 	for i := range ctx.Config.Rigs {
 		goFish := &ctx.Config.Rigs[i]
 
-		if goFish.CommitAuthor.Name == "" {
-			goFish.CommitAuthor.Name = "goreleaserbot"
-		}
-		if goFish.CommitAuthor.Email == "" {
-			goFish.CommitAuthor.Email = "goreleaser@carlosbecker.com"
-		}
+		goFish.CommitAuthor = commitauthor.Default(goFish.CommitAuthor)
 		if goFish.CommitMessageTemplate == "" {
 			goFish.CommitMessageTemplate = "GoFish fish food update for {{ .ProjectName }} version {{ .Tag }}"
 		}
@@ -297,12 +293,17 @@ func doPublish(ctx *context.Context, food *artifact.Artifact, cl client.Client)
 		return err
 	}
 
+	author, err := commitauthor.Get(ctx, rig.CommitAuthor)
+	if err != nil {
+		return err
+	}
+
 	content, err := os.ReadFile(food.Path)
 	if err != nil {
 		return err
 	}
 
-	return cl.CreateFile(ctx, rig.CommitAuthor, repo, content, gpath, msg)
+	return cl.CreateFile(ctx, author, repo, content, gpath, msg)
 }
 
 func buildFoodPath(folder, filename string) string {
