@@ -16,15 +16,9 @@ func TestSkipPipe(t *testing.T) {
 
 func TestIsSkip(t *testing.T) {
 	require.True(t, IsSkip(Skip("whatever")))
-	require.True(t, IsSkip(ErrSkipDisabledPipe))
 	require.False(t, IsSkip(errors.New("nope")))
 }
 
-func TestIsExpectedSkip(t *testing.T) {
-	require.True(t, IsSkip(ErrSkipDisabledPipe))
-	require.True(t, IsSkip(Skip("nope")))
-}
-
 func TestSkipMemento(t *testing.T) {
 	m := SkipMemento{}
 	m.Remember(Skip("foo"))
