@@ -36,45 +36,51 @@ func (Pipe) Default(ctx *context.Context) error {
 	ids := ids.New("sboms")
 	for i := range ctx.Config.SBOMs {
 		cfg := &ctx.Config.SBOMs[i]
-		if cfg.Cmd == "" {
-			cfg.Cmd = "syft"
+		if err := setConfigDefaults(cfg); err != nil {
+			return err
 		}
-		if cfg.Artifacts == "" {
-			cfg.Artifacts = "archive"
-		}
-		if len(cfg.Documents) == 0 {
-			switch cfg.Artifacts {
-			case "binary":
-				cfg.Documents = []string{"{{ .Binary }}_{{ .Version }}_{{ .Os }}_{{ .Arch }}.sbom"}
-			case "any":
-				cfg.Documents = []string{}
-			default:
-				cfg.Documents = []string{"{{ .ArtifactName }}.sbom"}
-			}
-		}
-		if cfg.Cmd == "syft" {
-			if len(cfg.Args) == 0 {
-				cfg.Args = []string{"$artifact", "--file", "$document", "--output", "spdx-json"}
-			}
-			if len(cfg.Env) == 0 && cfg.Artifacts == "source" || cfg.Artifacts == "archive" {
-				cfg.Env = []string{
-					"SYFT_FILE_METADATA_CATALOGER_ENABLED=true",
-				}
-			}
-		}
-		if cfg.ID == "" {
-			cfg.ID = "default"
-		}
-
-		if cfg.Artifacts != "any" && len(cfg.Documents) > 1 {
-			return fmt.Errorf("multiple SBOM outputs when artifacts=%q is unsupported", cfg.Artifacts)
-		}
-
 		ids.Inc(cfg.ID)
 	}
 	return ids.Validate()
 }
 
+func setConfigDefaults(cfg *config.SBOM) error {
+	if cfg.Cmd == "" {
+		cfg.Cmd = "syft"
+	}
+	if cfg.Artifacts == "" {
+		cfg.Artifacts = "archive"
+	}
+	if len(cfg.Documents) == 0 {
+		switch cfg.Artifacts {
+		case "binary":
+			cfg.Documents = []string{"{{ .Binary }}_{{ .Version }}_{{ .Os }}_{{ .Arch }}.sbom"}
+		case "any":
+			cfg.Documents = []string{}
+		default:
+			cfg.Documents = []string{"{{ .ArtifactName }}.sbom"}
+		}
+	}
+	if cfg.Cmd == "syft" {
+		if len(cfg.Args) == 0 {
+			cfg.Args = []string{"$artifact", "--file", "$document", "--output", "spdx-json"}
+		}
+		if len(cfg.Env) == 0 && (cfg.Artifacts == "source" || cfg.Artifacts == "archive") {
+			cfg.Env = []string{
+				"SYFT_FILE_METADATA_CATALOGER_ENABLED=true",
+			}
+		}
+	}
+	if cfg.ID == "" {
+		cfg.ID = "default"
+	}
+
+	if cfg.Artifacts != "any" && len(cfg.Documents) > 1 {
+		return fmt.Errorf("multiple SBOM outputs when artifacts=%q is unsupported", cfg.Artifacts)
+	}
+	return nil
+}
+
 // Run executes the Pipe.
 func (Pipe) Run(ctx *context.Context) error {
 	g := semerrgroup.New(ctx.Parallelism)
@@ -96,7 +102,7 @@ func catalogTask(ctx *context.Context, cfg config.SBOM) func() error {
 		case "archive":
 			filters = append(filters, artifact.ByType(artifact.UploadableArchive))
 		case "binary":
-			filters = append(filters, artifact.ByType(artifact.UploadableBinary))
+			filters = append(filters, artifact.ByBinaryLikeArtifacts(ctx.Artifacts))
 		case "package":
 			filters = append(filters, artifact.ByType(artifact.LinuxPackage))
 		case "any":
@@ -152,47 +158,14 @@ func subprocessDistPath(distDir string, pathRelativeToCwd string) (string, error
 }
 
 func catalogArtifact(ctx *context.Context, cfg config.SBOM, a *artifact.Artifact) ([]*artifact.Artifact, error) {
-	env := ctx.Env.Copy()
 	artifactDisplayName := "(any)"
-	templater := tmpl.New(ctx).WithEnv(env)
-
-	if a != nil {
-		procPath, err := subprocessDistPath(ctx.Config.Dist, a.Path)
-		if err != nil {
-			return nil, fmt.Errorf("cataloging artifacts failed: cannot determine artifact path for %q: %w", a.Path, err)
-		}
-		env["artifact"] = procPath
-		env["artifactID"] = a.ID()
-
-		templater = templater.WithArtifact(a, nil)
-		artifactDisplayName = a.Path
+	args, envs, paths, err := applyTemplate(ctx, cfg, a)
+	if err != nil {
+		return nil, fmt.Errorf("cataloging artifacts failed: %w", err)
 	}
 
-	var paths []string
-	for idx, sbom := range cfg.Documents {
-		input := filepath.Join(ctx.Config.Dist, expand(sbom, env))
-
-		path, err := templater.Apply(input)
-		if err != nil {
-			return nil, fmt.Errorf("cataloging artifacts failed: %s: invalid template: %w", input, err)
-		}
-
-		path, err = filepath.Abs(path)
-		if err != nil {
-			return nil, fmt.Errorf("cataloging artifacts failed: unable to create artifact path %q: %w", sbom, err)
-		}
-
-		procPath, err := subprocessDistPath(ctx.Config.Dist, path)
-		if err != nil {
-			return nil, fmt.Errorf("cataloging artifacts failed: cannot determine document path for %q: %w", path, err)
-		}
-
-		env[fmt.Sprintf("document%d", idx)] = procPath
-		if idx == 0 {
-			env["document"] = procPath
-		}
-
-		paths = append(paths, procPath)
+	if a != nil {
+		artifactDisplayName = a.Path
 	}
 
 	var names []string
@@ -202,16 +175,6 @@ func catalogArtifact(ctx *context.Context, cfg config.SBOM, a *artifact.Artifact
 
 	fields := log.Fields{"cmd": cfg.Cmd, "artifact": artifactDisplayName, "sboms": strings.Join(names, ", ")}
 
-	// nolint:prealloc
-	var args []string
-	for _, arg := range cfg.Args {
-		renderedArg, err := templater.Apply(expand(arg, env))
-		if err != nil {
-			return nil, fmt.Errorf("cataloging artifacts failed: %s: invalid template: %w", arg, err)
-		}
-		args = append(args, renderedArg)
-	}
-
 	// The GoASTScanner flags this as a security risk.
 	// However, this works as intended. The nosec annotation
 	// tells the scanner to ignore this.
@@ -223,7 +186,7 @@ func catalogArtifact(ctx *context.Context, cfg config.SBOM, a *artifact.Artifact
 			cmd.Env = append(cmd.Env, fmt.Sprintf("%s=%s", key, value))
 		}
 	}
-	cmd.Env = append(cmd.Env, cfg.Env...)
+	cmd.Env = append(cmd.Env, envs...)
 	cmd.Dir = ctx.Config.Dist
 
 	var b bytes.Buffer
@@ -238,27 +201,19 @@ func catalogArtifact(ctx *context.Context, cfg config.SBOM, a *artifact.Artifact
 
 	var artifacts []*artifact.Artifact
 
-	for _, sbom := range cfg.Documents {
-		templater = tmpl.New(ctx).WithEnv(env)
-		if a != nil {
-			env["artifact"] = a.Name
-			templater = templater.WithArtifact(a, nil)
+	for _, path := range paths {
+		if !filepath.IsAbs(path) {
+			path = filepath.Join(ctx.Config.Dist, path)
 		}
 
-		name, err := templater.Apply(expand(sbom, env))
+		matches, err := filepath.Glob(path)
 		if err != nil {
-			return nil, fmt.Errorf("cataloging artifacts failed: %s: invalid template: %w", a, err)
-		}
-
-		search := filepath.Join(ctx.Config.Dist, name)
-		matches, err := filepath.Glob(search)
-		if err != nil {
-			return nil, fmt.Errorf("cataloging artifacts: failed to find SBOM artifact %q: %w", search, err)
+			return nil, fmt.Errorf("cataloging artifacts: failed to find SBOM artifact %q: %w", path, err)
 		}
 		for _, match := range matches {
 			artifacts = append(artifacts, &artifact.Artifact{
 				Type: artifact.SBOM,
-				Name: name,
+				Name: filepath.Base(path),
 				Path: match,
 				Extra: map[string]interface{}{
 					artifact.ExtraID: cfg.ID,
@@ -271,6 +226,85 @@ func catalogArtifact(ctx *context.Context, cfg config.SBOM, a *artifact.Artifact
 	return artifacts, nil
 }
 
+func applyTemplate(ctx *context.Context, cfg config.SBOM, a *artifact.Artifact) ([]string, []string, []string, error) {
+	env := ctx.Env.Copy()
+	var extraEnvs []string
+	templater := tmpl.New(ctx).WithEnv(env)
+
+	if a != nil {
+		procPath, err := subprocessDistPath(ctx.Config.Dist, a.Path)
+		if err != nil {
+			return nil, nil, nil, fmt.Errorf("cataloging artifacts failed: cannot determine artifact path for %q: %w", a.Path, err)
+		}
+		extraEnvs = appendExtraEnv("artifact", procPath, extraEnvs, env)
+		extraEnvs = appendExtraEnv("artifactID", a.ID(), extraEnvs, env)
+
+		templater = templater.WithArtifact(a, nil)
+	}
+
+	for _, keyValue := range cfg.Env {
+		renderedKeyValue, err := templater.Apply(expand(keyValue, env))
+		if err != nil {
+			return nil, nil, nil, fmt.Errorf("env %q: invalid template: %w", keyValue, err)
+		}
+		extraEnvs = append(extraEnvs, renderedKeyValue)
+
+		fields := strings.Split(renderedKeyValue, "=")
+		key := fields[0]
+		renderedValue := strings.Join(fields[1:], "=")
+		env[key] = renderedValue
+	}
+
+	var paths []string
+	for idx, sbom := range cfg.Documents {
+		input := expand(sbom, env)
+		if !filepath.IsAbs(input) {
+			// assume any absolute path is handled correctly and assume that any relative path is not already
+			// adjusted to reference the dist path
+			input = filepath.Join(ctx.Config.Dist, input)
+		}
+
+		path, err := templater.Apply(input)
+		if err != nil {
+			return nil, nil, nil, fmt.Errorf("input %q: invalid template: %w", input, err)
+		}
+
+		path, err = filepath.Abs(path)
+		if err != nil {
+			return nil, nil, nil, fmt.Errorf("unable to create artifact path %q: %w", sbom, err)
+		}
+
+		procPath, err := subprocessDistPath(ctx.Config.Dist, path)
+		if err != nil {
+			return nil, nil, nil, fmt.Errorf("cannot determine document path for %q: %w", path, err)
+		}
+
+		extraEnvs = appendExtraEnv(fmt.Sprintf("document%d", idx), procPath, extraEnvs, env)
+		if idx == 0 {
+			extraEnvs = appendExtraEnv("document", procPath, extraEnvs, env)
+		}
+
+		paths = append(paths, procPath)
+	}
+
+	// nolint:prealloc
+	var args []string
+	for _, arg := range cfg.Args {
+		renderedArg, err := templater.Apply(expand(arg, env))
+		if err != nil {
+			return nil, nil, nil, fmt.Errorf("arg %q: invalid template: %w", arg, err)
+		}
+		args = append(args, renderedArg)
+	}
+
+	return args, extraEnvs, paths, nil
+}
+
+func appendExtraEnv(key, value string, envs []string, env map[string]string) []string {
+	env[key] = value
+	return append(envs, fmt.Sprintf("%s=%s", key, value))
+}
+
 func expand(s string, env map[string]string) string {
 	return os.Expand(s, func(key string) string {
 		return env[key]
